@@ -20,7 +20,7 @@
     if(class(input) == "list"){
       if(!all(sapply(input, class) == "RasterLayer")){stop("Invalid input list for \'", inputName ,"\'. List must be composed of tiled \'RasterLayer\' objects.")}
 
-      if(nrow(unique(do.call(rbind, lapply(input, raster::res)))) > 1){stop("Invalid input list for \'", inputName ,"\'. Inconsistent pixel resolution")}
+      raster::compareRaster(input, extent = FALSE, orig = TRUE, rowcol = FALSE, crs = TRUE, res = TRUE)
     }
 
     # If input is a character vector ensure that it refers to valid file path(s) to raster layers
@@ -59,7 +59,7 @@
 #' \code{\link{TileDetector}} will be used to detect the existing tiling scheme.
 #'
 #' Input for \code{TileApply} should be a list of RasterLayers, and so would typically be used
-#' in conjuction with \code{\link{TileInput}}.
+#' in conjunction with \code{\link{TileInput}}.
 #'
 #' @param inList a list of RasterLayers. Either a single raster (for which a tiling scheme may or may
 #' not be applied) or a list of existing tiles (for which a tiling scheme will be detected)
@@ -73,7 +73,7 @@
 #' @return The output of this function is a list of three \link[sp]{SpatialPolygonsDataFrame} objects:
 #'   \item{tilePolygons}{The tiling grid. Each polygon corresponds to the extent of a single unbuffered tile.}
 #'   \item{buffPolygons}{The buffered tiling grid. Each polygon corresponds to the extent of a buffered tile. These
-#'   polygons overlap with neighbouring tiles. If \code{buffer} is set to 0, this output will be identical to \code{tilePolygons}.}
+#'   polygons overlap with neighboring tiles. If \code{buffer} is set to 0, this output will be identical to \code{tilePolygons}.}
 #'   \item{nbuffPolygons}{Non-overlapping buffered tiles. These polygons remove overlapping buffers for adjacent tiles, but
 #'   preserve buffers for tiles on the edges of the tiling grid. Useful for "reassembling" data that had been originally broken
 #'   into tiles.}
